@@ -32,10 +32,11 @@
  * NULL, then it will fill the return pixbuf with the contents of
  * source_pixbuf.
  */
-GdkPixbuf *
-ev_document_misc_get_thumbnail_frame (int        width,
-				      int        height,
-				      GdkPixbuf *source_pixbuf)
+static GdkPixbuf *
+create_thumbnail_frame (int        width,
+			int        height,
+			GdkPixbuf *source_pixbuf,
+			gboolean   fill_bg)
 {
 	GdkPixbuf *retval;
 	guchar *data;
@@ -67,8 +68,10 @@ ev_document_misc_get_thumbnail_frame (int        width,
 	rowstride = gdk_pixbuf_get_rowstride (retval);
 
 	gdk_pixbuf_fill (retval, 0x000000ff);
-	for (i = 1; i < height_r + 1; i++)
-		memset (data + (rowstride * i) + 4, 0xffffffff, width_r * 4);
+	if (fill_bg) {
+		for (i = 1; i < height_r + 1; i++)
+			memset (data + (rowstride * i) + 4, 0xffffffff, width_r * 4);
+	}
 
 	/* copy the source pixbuf */
 	if (source_pixbuf)
@@ -91,6 +94,22 @@ ev_document_misc_get_thumbnail_frame (int        width,
 	return retval;
 }
 
+GdkPixbuf *
+ev_document_misc_get_thumbnail_frame (int        width,
+				      int        height,
+				      GdkPixbuf *source_pixbuf)
+{
+	return create_thumbnail_frame (width, height, source_pixbuf, TRUE);
+}
+
+GdkPixbuf *
+ev_document_misc_get_loading_thumbnail (int      width,
+					int      height,
+					gboolean inverted_colors)
+{
+	return create_thumbnail_frame (width, height, NULL, !inverted_colors);
+}
+
 void
 ev_document_misc_get_page_border_size (gint       page_width,
 				       gint       page_height,
@@ -114,42 +133,45 @@ ev_document_misc_get_page_border_size (gint       page_width,
 
 
 void
-ev_document_misc_paint_one_page (GdkDrawable  *drawable,
+ev_document_misc_paint_one_page (cairo_t      *cr,
 				 GtkWidget    *widget,
 				 GdkRectangle *area,
 				 GtkBorder    *border,
-				 gboolean highlight)
+				 gboolean      highlight,
+				 gboolean      inverted_colors)
 {
-	gdk_draw_rectangle (drawable,
-			    highlight ?
-			    	    widget->style->text_gc[widget->state] : widget->style->dark_gc[widget->state],
-			    TRUE,
-			    area->x,
-			    area->y,
-			    area->width,
-			    area->height);
-	gdk_draw_rectangle (drawable,
-			    widget->style->white_gc,
-			    TRUE,
-			    area->x + border->left,
-			    area->y + border->top,
-			    area->width - (border->left + border->right),
-			    area->height - (border->top + border->bottom));
-	gdk_draw_rectangle (drawable,
-			    widget->style->mid_gc[widget->state],
-			    TRUE,
-			    area->x,
-			    area->y + area->height - (border->bottom - border->top),
-			    border->bottom - border->top,
-			    border->bottom - border->top);
-	gdk_draw_rectangle (drawable,
-			    widget->style->mid_gc[widget->state],
-			    TRUE,
-			    area->x + area->width - (border->right - border->left),
-			    area->y,
-			    border->right - border->left,
-			    border->right - border->left);
+	GtkStyle    *style = gtk_widget_get_style (widget);
+	GtkStateType state = gtk_widget_get_state (widget);
 
+	gdk_cairo_set_source_color (cr, highlight ? &style->text[state] : &style->dark[state]);
+	gdk_cairo_rectangle (cr, area);
+	cairo_fill (cr);
+
+	if (inverted_colors)
+		cairo_set_source_rgb (cr, 0, 0, 0);
+	else
+		cairo_set_source_rgb (cr, 1, 1, 1);
+	cairo_rectangle (cr,
+			 area->x + border->left,
+			 area->y + border->top,
+			 area->width - (border->left + border->right),
+			 area->height - (border->top + border->bottom));
+	cairo_fill (cr);
+
+	gdk_cairo_set_source_color (cr, &style->mid[state]);
+	cairo_rectangle (cr,
+			 area->x,
+			 area->y + area->height - (border->bottom - border->top),
+			 border->bottom - border->top,
+			 border->bottom - border->top);
+	cairo_fill (cr);
+
+	cairo_rectangle (cr,
+			 area->x + area->width - (border->right - border->left),
+			 area->y,
+			 border->right - border->left,
+			 border->right - border->left);
+	cairo_fill (cr);
 }
 
 cairo_surface_t *
@@ -378,3 +400,26 @@ ev_document_misc_get_screen_dpi (GdkScreen *screen)
 
 	return (dp / di);
 }
+
+/* Returns a locale specific date and time representation */
+gchar *
+ev_document_misc_format_date (GTime utime)
+{
+	time_t time = (time_t) utime;
+	char s[256];
+	const char fmt_hack[] = "%c";
+	size_t len;
+#ifdef HAVE_LOCALTIME_R
+	struct tm t;
+	if (time == 0 || !localtime_r (&time, &t)) return NULL;
+	len = strftime (s, sizeof (s), fmt_hack, &t);
+#else
+	struct tm *t;
+	if (time == 0 || !(t = localtime (&time)) ) return NULL;
+	len = strftime (s, sizeof (s), fmt_hack, t);
+#endif
+
+	if (len == 0 || s[0] == '\0') return NULL;
+
+	return g_locale_to_utf8 (s, -1, NULL, NULL, NULL);
+}
